@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 #-*- coding:utf-8 -*-
 
 ###############################################################
@@ -13,13 +12,15 @@
 #
 ###############################################################
 
+
+#pylint: disable=wrong-import-position, unused-wildcard-import
+
 import sys
 import os
 import time
-import glob
 import random
-import codecs
 import unittest
+import io
 
 #We may need to do some path magic in order to find the clam.* imports
 
@@ -28,12 +29,10 @@ os.environ['PYTHONPATH'] = sys.path[0] + '/../../'
 
 #Import the CLAM Client API and CLAM Data API and other dependencies
 from clam.common.client import *
-from clam.common.data import *
+from clam.common.data import * #pylint: disable=redefined-builtin
 from clam.common.formats import *
 import clam.common.status
 
-import time
-
 class AuthServiceTest(unittest.TestCase):
     """Test basic operations with authentication"""
 
@@ -43,20 +42,51 @@ class AuthServiceTest(unittest.TestCase):
 
     def test1_index(self):
         """No Access Test - Testing inability to access index with wrong user credentials"""
-        self.assertRaises( PermissionDenied, self.client.index)
+        self.assertRaises( AuthRequired, self.client.index)
 
     def test2_create(self):
         """No Access Test - Testing inability to create project with wrong user credentials"""
-        self.assertRaises( PermissionDenied, self.client.create, 'basicservicetest')
+        self.assertRaises( AuthRequired, self.client.create, 'basicservicetest')
 
     def test3_project(self):
         """No Access Test - No project state retrieval with wrong user credentials"""
-        self.assertRaises( PermissionDenied, self.client.get, 'basicservicetest')
+        self.assertRaises( AuthRequired, self.client.get, 'basicservicetest')
+
+    def test4_index(self):
+        """Access Test - Testing ability to access porch despite wrong user credentials"""
+        data = self.client.porch()
+        self.assertTrue(data.system_id == "authtest")
+        self.assertTrue(data.profiles)
+        self.assertTrue(data.parameters)
+        self.assertFalse(data.projects)
+
+class NoAuthServiceTest(unittest.TestCase):
+    """Test basic operations without authentication"""
+
+    def setUp(self):
+        self.url = 'http://' + os.uname()[1] + ':8080'
+        self.client = CLAMClient(self.url)
+
+    def test1_porch(self):
+        """Access Test - Testing ability to access the porch (explicitly) without providing user credentials"""
+        data = self.client.porch()
+        self.assertTrue(data.system_id == "authtest")
+        self.assertTrue(data.profiles)
+        self.assertTrue(data.parameters)
+        self.assertFalse(data.projects)
+
+    def test2_porch(self):
+        """Access Test - Testing ability to access the porch (implicitly) without providing user credentials"""
+        data = self.client.getroot()
+        self.assertTrue(data.system_id == "authtest")
+        self.assertTrue(data.profiles)
+        self.assertTrue(data.parameters)
+        self.assertFalse(data.projects)
+
+    def test3_index(self):
+        """No Access Test - Testing inability to access the index"""
+        self.assertRaises( AuthRequired, self.client.index)
 
-    def test4_wait(self):
-        """No Access Test - Waiting 30s for lock to expire"""
-        time.sleep(30)
-        self.assertTrue(True)
 
 class BasicServiceTest(unittest.TestCase):
     """Test basic operations with authentication"""
@@ -73,6 +103,14 @@ class BasicServiceTest(unittest.TestCase):
         self.assertTrue(data.profiles)
         self.assertTrue(data.parameters)
 
+    def test1_2_porch(self):
+        """Basic Service Test - Porch and sanity"""
+        data = self.client.porch()
+        self.assertTrue(data.system_id == "authtest")
+        self.assertTrue(data.profiles)
+        self.assertTrue(data.parameters)
+        self.assertFalse(data.projects)
+
     def test2_1_create(self):
         """Basic Service Test - Project creation"""
         success = self.client.create('basicservicetest')
@@ -109,13 +147,19 @@ class BasicServiceTest(unittest.TestCase):
 
     def test2_4_upload(self):
         """Basic Service Test - File upload with extension"""
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
         data = self.client.get('basicservicetest')
         success = self.client.addinputfile('basicservicetest', data.inputtemplate('textinput'),'/tmp/servicetest.txt', language='fr')
         self.assertTrue(success)
 
+    def test2_4b_upload(self):
+        """Basic Service Test - Passing contents explicitly"""
+        data = self.client.get('basicservicetest')
+        success = self.client.addinput('basicservicetest', data.inputtemplate('textinput'),"On espère que tout ça marche bien.",filename='servicetest.txt', language='fr')
+        self.assertTrue(success)
+
     def test2_5_upload(self):
         """Basic Service Test - File upload verification"""
         data = self.client.get('basicservicetest')
@@ -137,7 +181,7 @@ class BasicServiceTest(unittest.TestCase):
 
     def test2_7_upload(self):
         """Basic Service Test - File upload without extension"""
-        f = codecs.open('/tmp/servicetest','w','utf-8')
+        f = io.open('/tmp/servicetest','w',encoding='utf-8')
         f.write(u"On espère que tout ça marche bien.")
         f.close()
         data = self.client.get('basicservicetest')
@@ -171,17 +215,16 @@ class BasicServiceTest(unittest.TestCase):
         try:
             success = self.client.addinputfile('basicservicetest', data.inputtemplate('textinput'),'/tmp/servicetest', language='nonexistant')
             self.assertFalse(success)
-        except ParameterError, e:
-            print e
-            self.assertTrue(True)
+        except ParameterError:
+            self.assertTrue(True) #pylint: disable=redundant-unittest-assert
 
     def test2_B_metadata(self):
         """Basic Service Test - Upload with explicit metadata file"""
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
-        f.write(u"On espère que tout ça marche bien.")
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
+        f.write("On espère que tout ça marche bien.")
         f.close()
-        f = codecs.open('/tmp/servicetest.txt.METADATA','w','utf-8')
-        f.write(u"""<?xml version="1.0" encoding="UTF-8"?>
+        f = io.open('/tmp/servicetest.txt.METADATA','w',encoding='utf-8')
+        f.write("""<?xml version="1.0" encoding="UTF-8"?>
 <CLAMMetaData format="PlainTextFormat" mimetype="text/plain" inputtemplate="textinput">
 <meta id="encoding">utf-8</meta>
 <meta id="author">proycon</meta>
@@ -204,7 +247,7 @@ class ExtensiveServiceTest(unittest.TestCase):
         self.client = CLAMClient(self.url,'proycon','secret')
         self.project = 'extservicetest'
         self.client.create(self.project)
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
         f.write(u"On espère que tout ça marche bien.")
         f.close()
 
@@ -220,7 +263,7 @@ class ExtensiveServiceTest(unittest.TestCase):
         while data.status != clam.common.status.DONE:
             time.sleep(1) #wait 1 second before polling status
             data = self.client.get(self.project) #get status again
-        self.assertFalse(data.errors)
+        self.assertFalse(data.errors, "Checking for absence of errors (" + data.errormsg + ")")
         self.assertTrue(isinstance(data.output, list))
         self.assertTrue('servicetest.txt.freqlist' in [ x.filename for x in data.output ])
         self.assertTrue('servicetest.txt.stats' in [ x.filename for x in data.output ])
@@ -242,8 +285,9 @@ class ExtensiveServiceTest(unittest.TestCase):
         try:
             data = self.client.start(self.project, casesensitive='nonexistant')
             self.assertTrue(data)
-        except ParameterError, e:
-            self.assertTrue(True)
+        except ParameterError:
+            self.assertTrue(True) #pylint: disable=redundant-unittest-assert
+
 
     def test3_conditionaloutput(self):
         """Extensive Service Test - Output conditional on parameter"""
@@ -273,7 +317,7 @@ class ExtensiveServiceTest(unittest.TestCase):
                 self.assertTrue(outputfile.metadata.provenance.outputtemplate_id == 'lexicon')
 
     def tearDown(self):
-        success = self.client.delete(self.project)
+        self.client.delete(self.project)
 
 
 
@@ -284,13 +328,13 @@ class ArchiveUploadTest(unittest.TestCase):
         self.client = CLAMClient(self.url,'proycon','secret')
         self.project = 'archivetest'
         self.client.create(self.project)
-        f = codecs.open('/tmp/servicetest.txt','w','utf-8')
+        f = io.open('/tmp/servicetest.txt','w',encoding='utf-8')
         f.write(u"On espère que tout ça marche bien.")
         f.close()
-        f = codecs.open('/tmp/servicetest2.txt','w','utf-8')
+        f = io.open('/tmp/servicetest2.txt','w',encoding='utf-8')
         f.write(u"Non, rien de rien, non je ne regrette rien.")
         f.close()
-        f = codecs.open('/tmp/servicetest3.txt','w','utf-8')
+        f = io.open('/tmp/servicetest3.txt','w',encoding='utf-8')
         f.write(u"Ni le mal qu'on m'a fait, ni le bien, tout ça me semble égal!")
         f.close()
         os.system('zip /tmp/servicetest.zip /tmp/servicetest.txt /tmp/servicetest2.txt /tmp/servicetest3.txt')
@@ -317,7 +361,7 @@ class ArchiveUploadTest(unittest.TestCase):
         self.assertTrue('servicetest3.txt' in [ x.filename for x in data.input ])
 
     def tearDown(self):
-        success = self.client.delete(self.project)
+        self.client.delete(self.project)
 
 if __name__ == '__main__':
-    unittest.main()
+    unittest.main(verbosity=2)
